/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.sync.oauth.helper;

import com.liferay.portal.kernel.service.ServiceContext;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;

/**
 * @author Shinn Lok
 */
@Component(immediate = true, service = SyncOAuthHelperUtil.class)
public class SyncOAuthHelperUtil {

	public static void enableOAuth(
			long companyId, ServiceContext serviceContext)
		throws Exception {

		SyncOAuthHelper syncOAuthHelper = getService();

		syncOAuthHelper.enableOAuth(companyId, serviceContext);
	}

	public static SyncOAuthHelper getService() {
		ServiceReference<SyncOAuthHelper> serviceReference =
			_bundleContext.getServiceReference(SyncOAuthHelper.class);

		if (serviceReference != null) {
			SyncOAuthHelper syncOAuthHelper = _bundleContext.getService(
				serviceReference);

			if (syncOAuthHelper != null) {
				return syncOAuthHelper;
			}
		}

		SyncOAuthHelper syncOAuthHelper = new SyncOAuthHelper() {

			public void enableOAuth(
				long companyId, ServiceContext serviceContext) {
			}

			public boolean isDeployed() {
				return false;
			}

			public boolean isOAuthApplicationAvailable(
				long oAuthApplicationId) {

				return false;
			}

		};

		return syncOAuthHelper;
	}

	public static boolean isDeployed() {
		SyncOAuthHelper syncOAuthHelper = getService();

		return syncOAuthHelper.isDeployed();
	}

	public static boolean isOAuthApplicationAvailable(long oAuthApplicationId) {
		SyncOAuthHelper syncOAuthService = getService();

		return syncOAuthService.isOAuthApplicationAvailable(oAuthApplicationId);
	}

	@Activate
	protected void activate(BundleContext bundleContext) {
		_bundleContext = bundleContext;
	}

	private static BundleContext _bundleContext;

}